@@ -14,9 +14,10 @@ class ConnectionSourceAdapter:
         pass
 
     @abstractmethod
-    def get_source_data(
+    def get_iterator(
             self,
-            integration: IntegrationBase
+            integration: IntegrationBase,
+            limit: int
     ) -> List[any]:
         pass
 
@@ -28,4 +29,3 @@ class ConnectionSourceAdapter:
             end: int
     ) -> List[any]:
         pass
-
