@@ -1,8 +1,6 @@
 from dataclasses import dataclass
-from dataclasses_json import dataclass_json
 
 
-@dataclass_json
 @dataclass
 class ConnectionBasicAuthentication:
     User: str = None
